# Contributing to PyMove
We love your input! We want to make contributing to this project as easy
 and transparent as possible, whether it's:

-   Reporting a bug
-   Discussing the current state of the code
-   Submitting a fix
-   Proposing new features
-   Becoming a maintainer

## We Develop with Github
We use github to host code, to track issues and feature requests,
 as well as accept pull requests.

## We Use [Github Flow](https://guides.github.com/introduction/flow/index.html)
All Code Changes Happen Through Pull Requests.
Pull requests are the best way to propose changes to the codebase.
We actively welcome your pull requests:

1.  Fork the repo and create your branch from `master`.
2.  If you've added code that should be tested, add tests.
3.  If you've changed APIs, update the documentation.
4.  Ensure the test suite passes.
5.  Make sure your code lints.
6.  Issue that pull request!

## Any contributions be under the [MIT Software License](http://choosealicense.com/licenses/mit/)
In short, when you submit code changes, your submissions are understood to be
under the same MIT License that covers the project.
Feel free to contact the maintainers if that's a concern.

## Report bugs using Github's [issues](https://github.com/InsightLab/PyMove/issues)
We use GitHub issues to track public bugs.
Report a bug by [opening a new issue](https://github.com/InsightLab/PyMove/issues/new).
It's that easy!

## Write bug reports with detail, background, and sample code
[This is an example of a bug report.](http://stackoverflow.com/q/12488905/180626).

**Great Bug Reports** tend to have:

-   A quick summary and/or background

-   Steps to reproduce
    -   Be specific!
    -   Give sample code if you can.

-   What you expected would happen

-   What actually happens

-   Notes (possibly including why you think this might be happening,
 or stuff you tried that didn't work)

People *love* thorough bug reports. I'm not even kidding.

## Use a Consistent Coding Style
We use `flake8` and `codacy` to standardize our code.
Some styles you shoud follow.
-   4 spaces for indentation rather than tabs
-   Use single quotes for strings
-   Try to keep your lines for up to 80 characters
-   Follow the instructions in our [code style](.code-style.md) file.

## Testing
It is important to know if our code is behaving like expected,
so it is important to run and develop tests for new implementations
-   Follow the instructions in our [testing](.testing.md) file.

## Documenting
To enable automatic documentation we use sphinx,
 follwing the Numpy Docstring style.
When creating new modules these need to be added to the docs.
-   Follow the instructions in our [documentation](.documentation.md) file.

## References
This document was adapted from <https://gist.github.com/briandk/3d2e8b3ec8daf5a27a62>,
 who follows the open-source contribution guidelines for [Facebook's Draft](https://github.com/facebook/draft-js/blob/a9316a723f9e918afde44dea68b5f9f39b7d9b00/CONTRIBUTING.md)
